Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(117)

Unified Diff: media/audio/audio_io.h

Issue 10830268: Allow audio system to handle synchronized low-latency audio I/O (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: Created 8 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: media/audio/audio_io.h
===================================================================
--- media/audio/audio_io.h (revision 156102)
+++ media/audio/audio_io.h (working copy)
@@ -57,12 +57,16 @@
// itself such as creating Windows or initializing COM.
class MEDIA_EXPORT AudioSourceCallback {
public:
// Provide more data by fully filling |audio_bus|. The source will return
// the number of frames it filled. |buffers_state| contains current state
// of the buffers, and can be used by the source to calculate delay.
- virtual int OnMoreData(AudioBus* audio_bus,
+ virtual int OnMoreData(AudioBus* dest,
AudioBuffersState buffers_state) = 0;
+ virtual int OnMoreIOData(AudioBus* source,
henrika (OOO until Aug 14) 2012/09/11 21:44:48 Comment?
+ AudioBus* dest,
+ AudioBuffersState buffers_state) = 0;
+
// There was an error while playing a buffer. Audio source cannot be
// destroyed yet. No direct action needed by the AudioStream, but it is
// a good place to stop accumulating sound data since is is likely that
@@ -57,12 +57,16 @@
class MEDIA_EXPORT AudioSourceCallback {
public:
- // Provide more data by fully filling |audio_bus|. The source will return
+ // Provide more data by fully filling |dest|. The source will return
// the number of frames it filled. |buffers_state| contains current state
// of the buffers, and can be used by the source to calculate delay.

Powered by Google App Engine
This is Rietveld 408576698